﻿using System;
using System.Linq;
using System.Web.Mvc;
using Mvc3RavenDbEmbed.Models;
using Raven.Client.Linq;

namespace Mvc3RavenDbEmbed.Controllers
{
    public class BookmarksController : BaseDocumentStoreController
    {
        public ViewResult Index()
        {
            var model = this.DocumentSession.Query<Bookmark>()
                    .OrderByDescending(i => i.DateCreated)
                    .ToList();
            return View(model);
        }

        public ViewResult Details(string id)
        {
            var model = this.DocumentSession.Load<Bookmark>(id);
            return View(model);
        }

        public ActionResult Create()
        {
            var model = new Bookmark();
            return View(model);
        } 

        [HttpPost]
        public ActionResult Create(Bookmark bookmark)
        {
            bookmark.DateCreated = DateTime.UtcNow;
            this.DocumentSession.Store(bookmark);
            return RedirectToAction("Index");
        }
        
        public ActionResult Edit(string id)
        {
            var model = this.DocumentSession.Load<Bookmark>(id);
            return View(model);
        }

        [HttpPost]
        public ActionResult Edit(Bookmark bookmark)
        {
            this.DocumentSession.Store(bookmark);
            return RedirectToAction("Index");
        }

        public ActionResult Delete(string id)
        {
            var model = this.DocumentSession.Load<Bookmark>(id);
            return View(model);
        }

        [HttpPost, ActionName("Delete")]
        public ActionResult DeleteConfirmed(string id)
        {
            this.DocumentSession.Advanced.DatabaseCommands.Delete(id, null);
            return RedirectToAction("Index");
        }

        public ViewResult Tag(string tag)
        {
            var model = new BookmarksByTagViewModel { Tag = tag };
            model.Bookmarks = this.DocumentSession.Query<Bookmark>()
                    .Where(i => i.Tags.Any(t => t == tag))
                    .OrderByDescending(i => i.DateCreated)
                    .ToList();
            return View(model);
        }
    }
}